@@ -315,31 +315,31 @@ def generate_vhs(
                 tape += f" +{left - 1} more"
             _logger.info(
                 term_width_line(
-                    f"{colorize("bold", "rendering VHS tapes...")} [{done}/{total}]{colorize("teal", tape)}"
+                    f"{colorize("bold", "rendering terminal GIFs...")} [{done}/{total}]{colorize("teal", tape)}"
                 ),
                 nonl=True,
             )
 
-        if (
-            len(outdated_files) > 1
-            and sphinx.util.parallel.parallel_available
-            and app.parallel <= 1
-        ):
+        if "READTHEDOCS" in environ:
+            parallel = app.config["vhs_n_jobs_read_the_docs"] or app.parallel or 1
+        else:
+            parallel = app.config["vhs_n_jobs"] or app.parallel or 1
+
+        if sphinx.util.parallel.parallel_available and parallel <= 1:
             _logger.info(
                 colorize(
                     "yellow",
-                    "rendering VHS tapes in sequence; pass -j auto to enable parallel run",
+                    "rendering terminal GIFs in sequence; pass -j auto to enable parallel run",
                 ),
                 type="vhs",
             )
-        if app.verbosity:
+        else:
             _logger.info(
-                f"{colorize("bold", "rendering VHS tapes")}: %s files, parallel=%s",
+                "rendering terminal GIFs: %s files, parallel=%s",
                 len(outdated_files),
-                app.parallel,
+                parallel,
                 type="vhs",
             )
-        else:
             on_tape_done(None)
 
         def worker(arg: VhsData):
@@ -353,7 +353,7 @@ def generate_vhs(
                 ) from e
             on_tape_done(arg.origname)
 
-        with ThreadPool(app.parallel or 1) as tasks:
+        with ThreadPool(parallel) as tasks:
             for _ in tasks.imap_unordered(worker, outdated_files):
                 pass
 
@@ -396,6 +396,8 @@ def setup(app: sphinx.application.Sphinx):
     app.add_config_value("vhs_auto_install_location", None, rebuild="")
     app.add_config_value("vhs_auto_install", True, rebuild="")
     app.add_config_value("vhs_cwd", None, rebuild="env")
+    app.add_config_value("vhs_n_jobs", None, rebuild="", types=int)
+    app.add_config_value("vhs_n_jobs_read_the_docs", 8, rebuild="", types=int)
     app.add_config_value(
         "vhs_cleanup_delay", timedelta(days=1), rebuild="env", types=timedelta
     )
